==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/registry/FEntityAttributes.java <==
package com.github.thedeathlycow.frostiful.registry;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.thermoo.api.ThermooAttributes;
import net.minecraft.class_1320;
import net.minecraft.class_1329;
import net.minecraft.class_2378;
import net.minecraft.class_5132;
import net.minecraft.class_6880;
import net.minecraft.class_7923;

public final class FEntityAttributes {
    public static final double BASE_MIN_TEMPERATURE = 45;

    public static final class_6880<class_1320> ICE_BREAK_DAMAGE = register(
            "generic.ice_breaker_damage",
            new class_1329(
                    "attribute.frostiful.generic.ice_break_damage", 3.0, 0, 1024.0
            ).method_26829(true)
    );

    // called from mixin
    public static void createLivingAttributes(class_5132.class_5133 builder) {
        builder.method_26867(ICE_BREAK_DAMAGE);
    }

    private static class_6880<class_1320> register(String name, class_1320 attribute) {
        return class_2378.method_47985(class_7923.field_41190, Frostiful.id(name), attribute);
    }

    public static void initialize() {
        Frostiful.LOGGER.debug("Initialized Frostiful attributes");

        ThermooAttributes.baseValueEvent(ThermooAttributes.MIN_TEMPERATURE).register((entity, baseValue) -> {
            if (entity.method_5864() == FEntityTypes.FROSTOLOGER) {
                return baseValue;
            } else {
                return baseValue + BASE_MIN_TEMPERATURE;
            }
        });
    }

    private FEntityAttributes() {

    }
}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/registry/FEntityAttributes.java <==
package com.github.thedeathlycow.frostiful.registry;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.thermoo.api.ThermooAttributes;
import net.minecraft.class_1320;
import net.minecraft.class_1329;
import net.minecraft.class_2378;
import net.minecraft.class_5132;
import net.minecraft.class_6880;
import net.minecraft.class_7923;

public final class FEntityAttributes {
    public static final double BASE_MIN_TEMPERATURE = 45;

    public static final class_6880<class_1320> ICE_BREAK_DAMAGE = register(
            "ice_breaker_damage",
            new class_1329(
                    "attribute.frostiful.ice_break_damage", 3.0, 0, 1024.0
            ).method_26829(true)
    );

    // called from mixin
    public static void createLivingAttributes(class_5132.class_5133 builder) {
        builder.method_26867(ICE_BREAK_DAMAGE);
    }

    private static class_6880<class_1320> register(String name, class_1320 attribute) {
        return class_2378.method_47985(class_7923.field_41190, Frostiful.id(name), attribute);
    }

    public static void initialize() {
        Frostiful.LOGGER.debug("Initialized Frostiful attributes");

        ThermooAttributes.baseValueEvent(ThermooAttributes.MIN_TEMPERATURE).register((entity, baseValue) -> {
            if (entity.method_5864() == FEntityTypes.FROSTOLOGER) {
                return baseValue;
            } else {
                return baseValue + BASE_MIN_TEMPERATURE;
            }
        });
    }

    private FEntityAttributes() {

    }
}
